#
# PySNMP MIB module IPOA-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IPOA-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:18:13 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ValueRangeConstraint, ConstraintsUnion, ConstraintsIntersection, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ValueRangeConstraint", "ConstraintsUnion", "ConstraintsIntersection", "SingleValueConstraint")
( InterfaceIndex, InterfaceIndexOrZero, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex", "InterfaceIndexOrZero")
( ipNetToMediaPhysAddress, ipAdEntAddr, ipNetToMediaIfIndex, ipNetToMediaNetAddress, ) = mibBuilder.importSymbols("IP-MIB", "ipNetToMediaPhysAddress", "ipAdEntAddr", "ipNetToMediaIfIndex", "ipNetToMediaNetAddress")
( ModuleCompliance, NotificationGroup, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup", "ObjectGroup")
( Bits, MibIdentifier, transmission, NotificationType, IpAddress, ModuleIdentity, Gauge32, TimeTicks, ObjectIdentity, Counter64, Unsigned32, MibScalar, MibTable, MibTableRow, MibTableColumn, Integer32, iso, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Bits", "MibIdentifier", "transmission", "NotificationType", "IpAddress", "ModuleIdentity", "Gauge32", "TimeTicks", "ObjectIdentity", "Counter64", "Unsigned32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Integer32", "iso", "Counter32")
( DisplayString, RowStatus, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "RowStatus", "TextualConvention")
ipoaMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 46))
if mibBuilder.loadTexts: ipoaMIB.setLastUpdated('9802090000Z')
if mibBuilder.loadTexts: ipoaMIB.setOrganization('IETF Internetworking Over NBMA Working\n                    Group (ion)')
if mibBuilder.loadTexts: ipoaMIB.setContactInfo('Maria Greene (greene@xedia.com)\n           Xedia Corp.\n\n           Jim Luciani (jluciani@BayNetworks.com)\n           Bay Networks\n\n           Kenneth White (kennethw@vnet.ibm.com)\n           IBM Corp.\n\n           Ted Kuo (tkuo@eos.ncsu.edu)\n           Bay Networks')
if mibBuilder.loadTexts: ipoaMIB.setDescription('This module defines a portion of the management\n          information base (MIB) for managing Classical IP and\n          ARP over ATM entities.')
class IpoaEncapsType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("llcSnap", 1), ("vcMuxed", 2), ("other", 3),)

class IpoaVpiInteger(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,255)

class IpoaVciInteger(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(0,65535)

class IpoaAtmAddr(OctetString, TextualConvention):
    displayHint = '1x'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,40)

class IpoaAtmConnKind(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))
    namedValues = NamedValues(("pvc", 1), ("svcIncoming", 2), ("svcOutgoing", 3), ("spvcInitiator", 4), ("spvcTarget", 5),)

ipoaObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 46, 1))
ipoaNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 46, 2))
ipoaConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 46, 3))
ipoaLisTrapEnable = MibScalar((1, 3, 6, 1, 2, 1, 10, 46, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: ipoaLisTrapEnable.setDescription('Indicates whether ipoaLisCreate and ipoaLisDelete\n          traps should be generated by this system.\n\n          By default, this object should have the value\n          enabled(1) for systems where ATMARP Servers are\n          present and disabled(2) on systems where only\n          clients reside.')
ipoaLisTable = MibTable((1, 3, 6, 1, 2, 1, 10, 46, 1, 2), )
if mibBuilder.loadTexts: ipoaLisTable.setDescription('There is one entry in this table for every Logical IP\n          Subnet (LIS) of which this system is a member.\n\n          The bulk of the objects in an ipoaLisEntry exists\n          to control ATMARP for a particular LIS.  In a PVC only\n          environment it is implementation dependent as to\n          whether this table should be supported.')
ipoaLisEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 46, 1, 2, 1), ).setIndexNames((0, "IPOA-MIB", "ipoaLisSubnetAddr"))
if mibBuilder.loadTexts: ipoaLisEntry.setDescription('Information about a single LIS of which this system\n          is a member.\n\n          Membership in a LIS is independent of the actual ATM\n          interfaces being used.  The ipoaLisTable defines\n          all LISs that a system is a member of.  The ipAddrTable\n          and the ipoaClientTable provides the mapping from local\n          IP address to ATM interface.  The ipoaLisIfMappingTable\n          provides the mappings between Logical IP Subnets and\n          interfaces.\n          The ipoaLisTable is indexed by ipoaLisSubnetAddr (IP\n          subnet address).  An entry in the ipoaLisTable should\n          exist for each ipAddrEntry that is associated with an\n          ATM related interface used for Classical IP and ARP\n          over ATM traffic.\n\n          Its ipAdEntAddr and ipAdEntNetMask when ANDed together\n          should equal the ipoaLisSubnetAddr of the corresponding\n          ipoaLisEntry.')
ipoaLisSubnetAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 2, 1, 1), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaLisSubnetAddr.setDescription('The IP subnet address associated with this LIS.')
ipoaLisDefaultMtu = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 2, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)).clone(9180)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaLisDefaultMtu.setDescription('The default MTU used within this LIS.  Note that the\n          actual MTU used for a VC between two members of the\n          LIS may be negotiated during connection setup and may\n          be different than this value.  The ipoaVcNegotiatedMtu\n          object indicates the actual MTU in use for a\n          particular VC.')
ipoaLisDefaultEncapsType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 2, 1, 3), IpoaEncapsType().clone('llcSnap')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaLisDefaultEncapsType.setDescription('The default encapsulation to use on VCs created for\n          this LIS.  Note that the actual encapsulation type may\n          be negotiated during connection setup and may be\n          different than this value.  The\n          ipoaVcNegotiatedEncapsType object indicates the actual\n          encapsulation in use for a particular VC.')
ipoaLisInactivityTimer = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 2, 1, 4), Integer32().clone(1200)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaLisInactivityTimer.setDescription('The time, in seconds, before a call established for an\n          ipNetToMediaEntry on a client will timeout due to no\n          traffic being passed on the VC.  A value of 0 implies\n          no time out.')
ipoaLisMinHoldingTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 2, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)).clone(60)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaLisMinHoldingTime.setDescription('The minimum amount of time, in seconds, that a call\n          will remain open.  If 0 then ipoaInactivityTimer will\n          completely determine when a call is terminated.')
ipoaLisQDepth = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 2, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)).clone(1)).setUnits('packets').setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaLisQDepth.setDescription('The maximum number of outstanding requests that are\n           allowed while waiting for ATMARP replies and\n           InATMARP replies for this LIS.')
ipoaLisMaxCalls = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 2, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535)).clone(500)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaLisMaxCalls.setDescription('The maximum number of SVCs that can be established\n          simultaneously for this LIS.')
ipoaLisCacheEntryAge = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 2, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(60,1200)).clone(900)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaLisCacheEntryAge.setDescription('The time, in seconds, before an ipNetToMediaEntry will\n          age out of the table.  Note that the default value will\n          be different for a client and a server.  An ATMARP\n          Server should use a default of 1200 and a client should\n          use 900.')
ipoaLisRetries = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 2, 1, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,10)).clone(2)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaLisRetries.setDescription('The number of times the ATMARP request will be retried\n          when no response is received in the timeout interval\n          indicated by ipoaLisTimeout.')
ipoaLisTimeout = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 2, 1, 10), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,60)).clone(10)).setUnits('seconds').setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaLisTimeout.setDescription('The time to wait, in seconds, before retransmission\n          of an ARP request.')
ipoaLisDefaultPeakCellRate = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 2, 1, 11), Integer32()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaLisDefaultPeakCellRate.setDescription("This object is the signalling parameter that\n           should be used when setting up all best effort\n           VCCs (Virtual Channel Connections).\n           This parameter applies to the forward and\n           backward direction on a per best effort VCC basis.\n           A value of zero implies that no configured default\n           exists and that local policy should be used to\n           determine the actual default to used during\n           call setup.  ATM Signaling Support for IP over ATM\n           (RFC 1755) recommends 1/10th of the ATM interface's\n           speed.")
ipoaLisActiveVcs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 2, 1, 12), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaLisActiveVcs.setDescription('Number of active SVCs for this LIS.')
ipoaLisRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 2, 1, 13), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaLisRowStatus.setDescription("This object allows entries to be created and deleted\n          in the ipoaLisTable.\n\n          When the ipoaLisRowStatus deleted (by setting this\n          object to destroy(6)), this has the side-effect of\n          removing all entries from the ipNetToMediaTable that\n          are associated with this LIS (in other words, it\n          flushes the entity's ATMARP cache).  It also removes\n          the ipoaVcTable entries that were associated with those\n          ipNetToMediaTable entries.  Destroying the row also\n          removes the corresponding entries in the\n          ipoaArpSrvrTable, ipoaArpClientTable,\n          ipoaLisIfMappingTable, and ipoaArpRemoteSrvrTable.\n\n          Entries in both the ipNetToMediaTable and the\n          ipoaVcTable that are associated with a\n          ipoaConfigPvcEntry are not affected by changes to\n          ipoaLisRowStatus.")
ipoaLisIfMappingTable = MibTable((1, 3, 6, 1, 2, 1, 10, 46, 1, 3), )
if mibBuilder.loadTexts: ipoaLisIfMappingTable.setDescription('There is one entry in this table for every combination\n           of ipoaLisEntry and IP over ATM interface.')
ipoaLisIfMappingEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 46, 1, 3, 1), ).setIndexNames((0, "IPOA-MIB", "ipoaLisSubnetAddr"), (0, "IPOA-MIB", "ipoaLisIfMappingIfIndex"))
if mibBuilder.loadTexts: ipoaLisIfMappingEntry.setDescription('Defines an entry in the ipoaLisIfMappingTable.')
ipoaLisIfMappingIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 3, 1, 1), InterfaceIndex())
if mibBuilder.loadTexts: ipoaLisIfMappingIfIndex.setDescription('The ipAdEntIfIndex object from an ipAddrEntry\n           is used as an index to this table when its\n           ipAdEntAddr is in the subnet implied by\n           ipoaLisSubnetAddr.')
ipoaLisIfMappingRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 3, 1, 2), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaLisIfMappingRowStatus.setDescription('This object allows entries to be created and deleted\n          in the ipoaLisIfMappingTable.')
ipoaArpClientTable = MibTable((1, 3, 6, 1, 2, 1, 10, 46, 1, 4), )
if mibBuilder.loadTexts: ipoaArpClientTable.setDescription('The ATMARP clients running on this system.')
ipoaArpClientEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1), ).setIndexNames((0, "IP-MIB", "ipAdEntAddr"))
if mibBuilder.loadTexts: ipoaArpClientEntry.setDescription("Information about a single ATMARP Client.  Clients\n          can be started and stopped by adding and removing\n          entries from this table.  An entry in the\n          ipoaArpClientTable has a corresponding entry in the\n          ipAddrTable.  Both are indexed by ipAdEntAddr.\n          The ifIndex and subnet mask of a client entry are the\n          ipAddrEntry's ipAdEntIfIndex and ipAdEntNetMask,\n          respectively.\n\n          Note that adding and removing entries from this table\n          may have the same effect on the corresponding\n          ipAddrTable entry.  Row creation of an entry in this\n          table requires that either the corresponding ipAddrTable\n          entry exists or that ipAdEntIfIndex and ipAdEntNetMask\n          be specified in the creation of an ipoaArpClientEntry\n          at a minimum in order to create the corresponding\n          ipAddrEntry.  Specification of ipAdEntBcastAddr and\n          ipAdEntReasmMaxSize to complete an ipAddrEntry is\n          implementation dependent.\n          Whether a corresponding ipAddrEntry is deleted during\n          the deletion of an ipoaArpClientEntry is considered\n          implementation dependent.")
ipoaArpClientAtmAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 1), IpoaAtmAddr()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaArpClientAtmAddr.setDescription('The ATM address of the client.')
ipoaArpClientSrvrInUse = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 2), IpoaAtmAddr().clone(hexValue="")).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpClientSrvrInUse.setDescription('The ATM address of the ATMARP Server,\n          ipoaArpRemoteSrvrAtmAddr, in use by this client.  A\n          zero length octet string implies that communication\n          with a Remote ATMARP Server is not in effect.')
ipoaArpClientInArpInReqs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpClientInArpInReqs.setDescription('The number of InATMARP requests received by this\n          client.')
ipoaArpClientInArpOutReqs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpClientInArpOutReqs.setDescription('The number of InATMARP requests sent by this client.')
ipoaArpClientInArpInReplies = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpClientInArpInReplies.setDescription('The number of InATMARP replies received by this\n          client.')
ipoaArpClientInArpOutReplies = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpClientInArpOutReplies.setDescription('Total number of InATMARP replies sent by this client.')
ipoaArpClientInArpInvalidInReqs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpClientInArpInvalidInReqs.setDescription('The number of times that this client detected an\n          invalid InATMARP request.')
ipoaArpClientInArpInvalidOutReqs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpClientInArpInvalidOutReqs.setDescription('The number of times that this client did not\n          receive an InATMARP reply.')
ipoaArpClientArpInReqs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpClientArpInReqs.setDescription('Total number of ATMARP requests received by this\n          client.')
ipoaArpClientArpOutReqs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpClientArpOutReqs.setDescription('Total number of ATMARP requests sent by this client.')
ipoaArpClientArpInReplies = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpClientArpInReplies.setDescription('Total number of ATMARP replies received by this\n          client.')
ipoaArpClientArpOutReplies = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpClientArpOutReplies.setDescription('Total number of ATMARP replies sent by this client.')
ipoaArpClientArpInNaks = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpClientArpInNaks.setDescription('Total number of negative ATMARP replies\n           received by this client.')
ipoaArpClientArpOutNaks = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpClientArpOutNaks.setDescription('Total number of negative ATMARP replies sent by\n          this client.\n\n          Classic IP and ARP over ATM does not require an\n          ATMARP client to transmit an ATMARP_NAK upon\n          receipt of an ATMARP request from another ATMARP\n          client.  However, implementation experience has\n          shown that this error condition is somewhat easy\n          to create inadvertently by configuring one ATMARP\n          client with an ipoaArpRemoteSrvrTable entry\n          containing an ipoaArpRemoteSrvrAtmAddr value which\n          is the ATM address of another ATMARP client-only\n          system.\n\n          If an ATMARP client supports the transmission of\n          ATMARP_NAKs, then it should increment\n          ipoaArpClientArpOutNaks each time it transmits\n          an ATMARP_NAK.  Otherwise, support of this\n          object is considered optional.')
ipoaArpClientArpUnknownOps = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpClientArpUnknownOps.setDescription('The number of times that this client received\n           an ATMARP message with an operation code for which\n           it is not coded to support.')
ipoaArpClientArpNoSrvrResps = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpClientArpNoSrvrResps.setDescription('The number of times this client failed to receive\n           a response from a ATMARP Server within the\n           ipoaLisTimeout value for ipoaLisRetries times.\n           This may imply that the client will re-elect a\n           new primary ATMARP Server for this LIS from the\n           ipoaArpRemoteSrvrTable.')
ipoaArpClientRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 4, 1, 17), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaArpClientRowStatus.setDescription('This object allows entries to be created and\n          deleted from the ipoaArpClientTable.')
ipoaArpSrvrTable = MibTable((1, 3, 6, 1, 2, 1, 10, 46, 1, 5), )
if mibBuilder.loadTexts: ipoaArpSrvrTable.setDescription('The ATMARP Servers running on this system.')
ipoaArpSrvrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 46, 1, 5, 1), ).setIndexNames((0, "IP-MIB", "ipAdEntAddr"), (0, "IPOA-MIB", "ipoaArpSrvrAddr"))
if mibBuilder.loadTexts: ipoaArpSrvrEntry.setDescription("Information about an ATMARP Server within a LIS.  An\n          entry in this table has two indexes: first ipAdEntAddr,\n          which is the IP address that this system uses as a\n          member of the LIS, and then ipoaArpSrvrAddr, which is\n          the ATM address of the ATMARP Server.\n\n          Entries may be created by a management application\n          using the ipoaArpSrvrRowStatus object.  Entries in this\n          table may also be created by the system and not by a\n          management application, for example via ILMI.\n\n          Entries in this table may be deleted by setting the\n          ipoaArpSrvrRowStatus object to 'destroy(6)'.  This\n          includes entries that were added by the system and not\n          by a management application.")
ipoaArpSrvrAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 5, 1, 1), IpoaAtmAddr())
if mibBuilder.loadTexts: ipoaArpSrvrAddr.setDescription('The ATM address of the ATMARP Server.')
ipoaArpSrvrLis = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 5, 1, 2), IpAddress()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaArpSrvrLis.setDescription('The subnet address that identifies the LIS with\n          which this server is associated.')
ipoaArpSrvrInArpInReqs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 5, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpSrvrInArpInReqs.setDescription('The number of InATMARP requests received by this\n          ATMARP Server.')
ipoaArpSrvrInArpOutReqs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 5, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpSrvrInArpOutReqs.setDescription('The number of InATMARP requests sent by this ATMARP\n          Server.')
ipoaArpSrvrInArpInReplies = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 5, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpSrvrInArpInReplies.setDescription('The number of InATMARP replies received by this\n          ATMARP Server.')
ipoaArpSrvrInArpOutReplies = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 5, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpSrvrInArpOutReplies.setDescription('The number of InATMARP replies sent by this ATMARP\n          Server.')
ipoaArpSrvrInArpInvalidInReqs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 5, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpSrvrInArpInvalidInReqs.setDescription('The number of invalid InATMARP requests received by\n           this ATMARP Server.')
ipoaArpSrvrInArpInvalidOutReqs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 5, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpSrvrInArpInvalidOutReqs.setDescription('The number of times that this server did not receive\n           an InATMARP reply.')
ipoaArpSrvrArpInReqs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 5, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpSrvrArpInReqs.setDescription('Total number of ATMARP requests received by this\n          ATMARP Server.')
ipoaArpSrvrArpOutReplies = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 5, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpSrvrArpOutReplies.setDescription('Total number of ATMARP replies sent by this ATMARP\n          Server.')
ipoaArpSrvrArpOutNaks = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 5, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpSrvrArpOutNaks.setDescription('Total number of negative ATMARP replies sent by this\n           ATMARP Server.')
ipoaArpSrvrArpDupIpAddrs = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 5, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpSrvrArpDupIpAddrs.setDescription('The number of times that a duplicate IP address was\n           detected by this ATMARP Server.')
ipoaArpSrvrArpUnknownOps = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 5, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpSrvrArpUnknownOps.setDescription('The number of times that this ATMARP Server received\n           an ATMARP message with an operation code for which it\n           is not coded to support.')
ipoaArpSrvrRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 5, 1, 14), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaArpSrvrRowStatus.setDescription('This object allows entries to be created and deleted\n          from the ipoaArpSrvrTable.')
ipoaArpRemoteSrvrTable = MibTable((1, 3, 6, 1, 2, 1, 10, 46, 1, 6), )
if mibBuilder.loadTexts: ipoaArpRemoteSrvrTable.setDescription('A table of non-local ATMARP Servers associated with a\n          LIS.  An entry in this table has three indexes: first\n          the ipoaLisSubnetAddr of the LIS for which the\n          corresponding ATMARP Server provides ATMARP services,\n          then the ipoaArpRemoteSrvrAtmAddr, which is the ATM\n          address of the remote ATMARP Server, and finally the\n          ifIndex of the interface on which the VC to the ATMARP\n          Remote Server will be opened.  An ifIndex value of 0\n          should be used when a single VC is to be shared for\n          ATMARP purposes by multiple interfaces.')
ipoaArpRemoteSrvrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 46, 1, 6, 1), ).setIndexNames((0, "IPOA-MIB", "ipoaLisSubnetAddr"), (0, "IPOA-MIB", "ipoaArpRemoteSrvrAtmAddr"), (0, "IPOA-MIB", "ipoaArpRemoteSrvrIfIndex"))
if mibBuilder.loadTexts: ipoaArpRemoteSrvrEntry.setDescription('Information about one non-local ATMARP Server.')
ipoaArpRemoteSrvrAtmAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 6, 1, 1), IpoaAtmAddr())
if mibBuilder.loadTexts: ipoaArpRemoteSrvrAtmAddr.setDescription('The ATM address of the remote ATMARP Server.')
ipoaArpRemoteSrvrRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 6, 1, 2), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaArpRemoteSrvrRowStatus.setDescription('This object allows entries to be created and deleted\n          from the ipoaArpRemoteSrvrTable.\n\n          Deleting an ipoaArpRemoteSrvrEntry (by setting this\n          object to destroy(6)) may affect ipoaArpClientTable\n          entries.  The object ipoaArpClientSrvrInUse in an\n          ipoaArpClientSrvrEntry may contain the ATM address\n          of an ATMARP Remote Server whose entry in the\n          ipoaArpRemoteSrvrTable is being removed.  In this\n          case, any corresponding ipoaArpClientSrvrInUse\n          objects should be at a minimum invalidated by\n          setting their values to that of a zero length\n          OCTET STRING.\n\n          The value of ipoaArpRemoteSrvrOperStatus should be\n          consistent with that of ipoaArpRemoteSrvrRowStatus.\n          For example, successfully setting the value of\n          this object to notInService(2) after its being in\n          the up(1) state should result in\n          ipoaArpRemoteSrvrOperStatus being set to down(2)\n          if currently up(1).')
ipoaArpRemoteSrvrIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 6, 1, 3), InterfaceIndexOrZero())
if mibBuilder.loadTexts: ipoaArpRemoteSrvrIfIndex.setDescription('The ifIndex of the interface that the VC to the\n           Remote ATMARP Server is associated with.')
ipoaArpRemoteSrvrIpAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 6, 1, 4), IpAddress().clone(hexValue="00000000")).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpRemoteSrvrIpAddr.setDescription("The IP Address of the Remote ATMARP Server.  A\n          value of 0.0.0.0 implies that this address isn't\n          known.")
ipoaArpRemoteSrvrAdminStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 6, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),)).clone('down')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaArpRemoteSrvrAdminStatus.setDescription('The desired state for use of the ATMARP Server\n           represented by an entry in this table.\n           ipoaArpRemoteSrvrAdminStatus values:\n\n           up(1)   - Attempt to activate use of the\n                     ATMARP Server represented by this\n                     entry in the ipoaArpRemoteSrvrTable.\n           down(2) - Deactivate use of this ATMARP\n                     Server.\n\n           When a managed system creates an entry in this\n           table ipoaArpRemoteSrvrAdminStatus and\n           ipoaArpRemoteSrvrOperStatus are initialized as\n           down(2) by default.')
ipoaArpRemoteSrvrOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 6, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("up", 1), ("down", 2),)).clone('down')).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaArpRemoteSrvrOperStatus.setDescription('The current operational state for use of a Remote\n           ATMARP Server.  An up(1) entry has a VC\n           established to the respective Remote ATMARP\n           Server:\n\n           up(1)  - A VC exists to Remote ATMARP Server\n                    whose IP Address is stored in\n                    ipoaArpRemoteSrvrIpAddr.  This VC can\n                    be determined by searching the\n                    ipoaVcTable using\n                    ipoaArpRemoteSrvrIfIndex (if not 0,\n                    otherwise ignore ipNetToMediaIfIndex\n                    index) and ipoaArpRemoteSrvrIpAddr.\n                    An ipoaArpClientEntry should exist\n                    with its ipoaArpClientSrvrInUse\n                    object having the same value as\n                    ipoaArpRemoteSrvrAtmAddr.\n\n          down(2) - Entry exists without an active VC to\n                    the Remote ATMARP Server.\n\n          Transition from up(1) to down(2)\n          status may affect ipoaArpClientTable entries.\n          The object ipoaArpClientSrvrInUse in an\n          ipoaArpClientSrvrEntry may contain the ATM address\n          of an ATMARP Remote Server whose entry in the\n          ipoaArpRemoteSrvrTable is being deactivated.  In\n          this case, any corresponding ipoaArpClientSrvrInUse\n          objects should be at a minimum invalidated by\n          setting their values to that of a zero length\n          OCTET STRING.\n\n          If ipoaArpRemoteSrvrAdminStatus is down(2) then\n          ipoaArpRemoteSrvrOperStatus should be down(2).\n          If ipoaArpRemoteSrvrAdminStatus is changed to\n          up(1) then ipoaArpRemoteSrvrOperStatus should\n          change to up(1) if the Remote ATMARP Server\n          entry can be activated.')
ipoaVcTable = MibTable((1, 3, 6, 1, 2, 1, 10, 46, 1, 7), )
if mibBuilder.loadTexts: ipoaVcTable.setDescription("A system that supports IP over ATM is an IP system and\n          therefore MUST support all of the appropriate tables in\n          the SNMPv2-MIB (RFC 1907), the IF-MIB (RFC 2233),\n          the IP-MIB (RFC 2011), the TCP-MIB (RFC 2012), and\n          the UDP-MIB (RFC 2013).  This includes the\n          ipNetToMediaTable (the ARP cache) that is defined\n          within the IP-MIB (RFC 2011).  The ipoaVcTable\n          keeps a set of VCs for each entry in the ARP cache\n          that was put there by an IP over ATM system acting\n          as either a host or server.  The ipoaVcTable doesn't\n          augment the ipNetToMediaTable (ARP Cache) since the\n          the correspondence between tables is not necessarily\n          one-to-one.\n\n          An ipNetToMediaPhysAddress object should contain the\n          content as defined by the IpoaAtmAddr textual\n          convention when used to hold an IPOA-MIB ATM Address.")
ipoaVcEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 46, 1, 7, 1), ).setIndexNames((0, "IP-MIB", "ipNetToMediaIfIndex"), (0, "IP-MIB", "ipNetToMediaNetAddress"), (0, "IPOA-MIB", "ipoaVcVpi"), (0, "IPOA-MIB", "ipoaVcVci"))
if mibBuilder.loadTexts: ipoaVcEntry.setDescription('A VC (permanent or switched) that this host or server\n          has opened with another member of a LIS.  Additional\n          information can be determined about the VC from the\n          ATM-MIB.\n\n          Entries in this table cannot be created by management\n          applications.\n\n          In an SVC environment, an entry is automatically added\n          by the system as the result of ATMARP processing.\n\n          In a PVC environment, an entry is automatically added\n          to this table when an entry is created in the\n          ipoaConfigPvcTable and the IP Address at the remote\n          end of the PVC is discovered using InATMARP.  An\n          entry also is added to the ipNetToMediaTable.')
ipoaVcVpi = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 7, 1, 1), IpoaVpiInteger())
if mibBuilder.loadTexts: ipoaVcVpi.setDescription('The VPI value for the Virtual Circuit.')
ipoaVcVci = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 7, 1, 2), IpoaVciInteger())
if mibBuilder.loadTexts: ipoaVcVci.setDescription('The VCI value for the Virtual Circuit.')
ipoaVcType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 7, 1, 3), IpoaAtmConnKind()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaVcType.setDescription('The type of the Virtual Circuit.')
ipoaVcNegotiatedEncapsType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 7, 1, 4), IpoaEncapsType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaVcNegotiatedEncapsType.setDescription('The encapsulation type used when communicating over\n          this circuit.')
ipoaVcNegotiatedMtu = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 7, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: ipoaVcNegotiatedMtu.setDescription('The MTU used when communicating over this circuit.')
ipoaConfigPvcTable = MibTable((1, 3, 6, 1, 2, 1, 10, 46, 1, 8), )
if mibBuilder.loadTexts: ipoaConfigPvcTable.setDescription('This table MUST be supported when PVCs are intended to\n          be supported in order to enable the setup of PVCs for\n          use by IP.')
ipoaConfigPvcEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 46, 1, 8, 1), ).setIndexNames((0, "IPOA-MIB", "ipoaConfigPvcIfIndex"), (0, "IPOA-MIB", "ipoaConfigPvcVpi"), (0, "IPOA-MIB", "ipoaConfigPvcVci"))
if mibBuilder.loadTexts: ipoaConfigPvcEntry.setDescription('Defines a single PVC that exists at this host for\n          use by IP.')
ipoaConfigPvcIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 8, 1, 1), InterfaceIndex())
if mibBuilder.loadTexts: ipoaConfigPvcIfIndex.setDescription('The ifIndex of the ATM Interface that this PVC\n           is associated with.')
ipoaConfigPvcVpi = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 8, 1, 2), IpoaVpiInteger())
if mibBuilder.loadTexts: ipoaConfigPvcVpi.setDescription('The VPI value for the Virtual Circuit.')
ipoaConfigPvcVci = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 8, 1, 3), IpoaVciInteger())
if mibBuilder.loadTexts: ipoaConfigPvcVci.setDescription('The VCI value for the Virtual Circuit.')
ipoaConfigPvcDefaultMtu = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 8, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535)).clone(9180)).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaConfigPvcDefaultMtu.setDescription('Classical IP and ARP over ATM allows use of\n         other MTU values for PVCs but considers how a\n         value other than 9180 could be selected to be out\n         of scope.  ipoaConfigPvcDefaultMtu can be used to\n         configure the MTU to be used for the PVC.\n         Both ends MUST have the same value configured.')
ipoaConfigPvcRowStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 46, 1, 8, 1, 5), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: ipoaConfigPvcRowStatus.setDescription('This object allows rows to be created and deleted in\n         the ipoaConfigPvcTable.  Creation of an entry in this\n         table should eventually result in the creation of an\n         ipNetToMediaEntry and a corresponding ipoaVcEntry\n         after InATMARP has determined the destination address\n         of the remote system that the PVC is connected to.\n         Setting this object to destroy(6) should remove the\n         corresponding ipNetToMediaTable and ipoaVcTable\n         entries.')
ipoaTrapPrefix = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 46, 2, 0))
ipoaMtuExceeded = NotificationType((1, 3, 6, 1, 2, 1, 10, 46, 2, 0, 1)).setObjects(*(("IPOA-MIB", "ipoaVcNegotiatedMtu"),))
if mibBuilder.loadTexts: ipoaMtuExceeded.setDescription('A frame was received that exceeds the negotiated\n          MTU size.  The VPI and VCI of the VC for which this\n          condition was detected can be determined from the\n          index values for ipoaVcNegotiatedMtu.  In addition,\n          the ifIndex and IP Address can be determined as\n          well (refer to the ipoaVcTable).')
ipoaDuplicateIpAddress = NotificationType((1, 3, 6, 1, 2, 1, 10, 46, 2, 0, 2)).setObjects(*(("IPOA-MIB", "ipNetToMediaIfIndex"), ("IPOA-MIB", "ipNetToMediaNetAddress"), ("IPOA-MIB", "ipNetToMediaPhysAddress"), ("IPOA-MIB", "ipNetToMediaPhysAddress"),))
if mibBuilder.loadTexts: ipoaDuplicateIpAddress.setDescription('The ATMARP Server has detected more than one ATM end\n          point attempting to associate the same IP address with\n          different ATM addresses.')
ipoaLisCreate = NotificationType((1, 3, 6, 1, 2, 1, 10, 46, 2, 0, 3)).setObjects(*(("IPOA-MIB", "ipoaLisSubnetAddr"),))
if mibBuilder.loadTexts: ipoaLisCreate.setDescription('Generation of this trap occurs when an ipoaLisEntry is\n          created while the ipoaLisTrapEnable.0 object has the\n          value enabled(1).')
ipoaLisDelete = NotificationType((1, 3, 6, 1, 2, 1, 10, 46, 2, 0, 4)).setObjects(*(("IPOA-MIB", "ipoaLisSubnetAddr"),))
if mibBuilder.loadTexts: ipoaLisDelete.setDescription('Generation of this trap occurs when an ipoaLisEntry is\n          deleted while the ipoaLisTrapEnable.0 object has the\n          value enabled(1).')
ipoaGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 46, 3, 1))
ipoaCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 46, 3, 2))
ipoaCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 46, 3, 2, 1)).setObjects(*(("IPOA-MIB", "ipoaGeneralGroup"), ("IPOA-MIB", "ipoaBasicNotificationsGroup"), ("IPOA-MIB", "ipoaClientGroup"), ("IPOA-MIB", "ipoaSrvrGroup"), ("IPOA-MIB", "ipoaSrvrNotificationsGroup"), ("IPOA-MIB", "ipoaLisNotificationsGroup"), ("IPOA-MIB", "ipoaLisTableGroup"),))
if mibBuilder.loadTexts: ipoaCompliance.setDescription('The compliance statement for agents that support the\n          IPOA-MIB.')
ipoaGeneralGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 46, 3, 1, 1)).setObjects(*(("IPOA-MIB", "ipoaVcType"), ("IPOA-MIB", "ipoaVcNegotiatedEncapsType"), ("IPOA-MIB", "ipoaVcNegotiatedMtu"), ("IPOA-MIB", "ipoaConfigPvcDefaultMtu"), ("IPOA-MIB", "ipoaConfigPvcRowStatus"),))
if mibBuilder.loadTexts: ipoaGeneralGroup.setDescription('This group is mandatory for all IP over ATM entities.')
ipoaClientGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 46, 3, 1, 2)).setObjects(*(("IPOA-MIB", "ipoaArpClientAtmAddr"), ("IPOA-MIB", "ipoaArpClientSrvrInUse"), ("IPOA-MIB", "ipoaArpClientInArpInReqs"), ("IPOA-MIB", "ipoaArpClientInArpOutReqs"), ("IPOA-MIB", "ipoaArpClientInArpInReplies"), ("IPOA-MIB", "ipoaArpClientInArpOutReplies"), ("IPOA-MIB", "ipoaArpClientInArpInvalidInReqs"), ("IPOA-MIB", "ipoaArpClientInArpInvalidOutReqs"), ("IPOA-MIB", "ipoaArpClientArpInReqs"), ("IPOA-MIB", "ipoaArpClientArpOutReqs"), ("IPOA-MIB", "ipoaArpClientArpInReplies"), ("IPOA-MIB", "ipoaArpClientArpOutReplies"), ("IPOA-MIB", "ipoaArpClientArpInNaks"), ("IPOA-MIB", "ipoaArpClientArpOutNaks"), ("IPOA-MIB", "ipoaArpClientArpUnknownOps"), ("IPOA-MIB", "ipoaArpClientArpNoSrvrResps"), ("IPOA-MIB", "ipoaArpClientRowStatus"),))
if mibBuilder.loadTexts: ipoaClientGroup.setDescription('This group is mandatory for all hosts where an IP\n          over ATM client is present.')
ipoaSrvrGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 46, 3, 1, 3)).setObjects(*(("IPOA-MIB", "ipoaArpSrvrLis"), ("IPOA-MIB", "ipoaArpSrvrInArpInReqs"), ("IPOA-MIB", "ipoaArpSrvrInArpOutReqs"), ("IPOA-MIB", "ipoaArpSrvrInArpInReplies"), ("IPOA-MIB", "ipoaArpSrvrInArpOutReplies"), ("IPOA-MIB", "ipoaArpSrvrInArpInvalidInReqs"), ("IPOA-MIB", "ipoaArpSrvrInArpInvalidOutReqs"), ("IPOA-MIB", "ipoaArpSrvrArpInReqs"), ("IPOA-MIB", "ipoaArpSrvrArpOutReplies"), ("IPOA-MIB", "ipoaArpSrvrArpOutNaks"), ("IPOA-MIB", "ipoaArpSrvrArpDupIpAddrs"), ("IPOA-MIB", "ipoaArpSrvrArpUnknownOps"), ("IPOA-MIB", "ipoaArpSrvrRowStatus"),))
if mibBuilder.loadTexts: ipoaSrvrGroup.setDescription('This group is mandatory for all hosts where ATMARP\n          Servers are present.')
ipoaBasicNotificationsGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 10, 46, 3, 1, 4)).setObjects(*(("IPOA-MIB", "ipoaMtuExceeded"),))
if mibBuilder.loadTexts: ipoaBasicNotificationsGroup.setDescription('The notification which an IP over ATM entity\n          is required to implement.')
ipoaSrvrNotificationsGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 10, 46, 3, 1, 5)).setObjects(*(("IPOA-MIB", "ipoaDuplicateIpAddress"),))
if mibBuilder.loadTexts: ipoaSrvrNotificationsGroup.setDescription('The notification which an IP over ATM ATMARP\n              Server is required to implement.')
ipoaLisNotificationsGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 10, 46, 3, 1, 6)).setObjects(*(("IPOA-MIB", "ipoaLisCreate"), ("IPOA-MIB", "ipoaLisDelete"),))
if mibBuilder.loadTexts: ipoaLisNotificationsGroup.setDescription('The LIS-related notifications which are required\n              to be implemented by an IP over ATM ATMARP server,\n              as well as by any IP over ATM client which allows\n              ipoaLisTrapEnable to be set to enabled(1).')
ipoaLisTableGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 46, 3, 1, 7)).setObjects(*(("IPOA-MIB", "ipoaLisTrapEnable"), ("IPOA-MIB", "ipoaLisSubnetAddr"), ("IPOA-MIB", "ipoaLisDefaultMtu"), ("IPOA-MIB", "ipoaLisDefaultEncapsType"), ("IPOA-MIB", "ipoaLisInactivityTimer"), ("IPOA-MIB", "ipoaLisMinHoldingTime"), ("IPOA-MIB", "ipoaLisQDepth"), ("IPOA-MIB", "ipoaLisMaxCalls"), ("IPOA-MIB", "ipoaLisCacheEntryAge"), ("IPOA-MIB", "ipoaLisRetries"), ("IPOA-MIB", "ipoaLisTimeout"), ("IPOA-MIB", "ipoaLisDefaultPeakCellRate"), ("IPOA-MIB", "ipoaLisActiveVcs"), ("IPOA-MIB", "ipoaLisRowStatus"), ("IPOA-MIB", "ipoaLisIfMappingRowStatus"), ("IPOA-MIB", "ipoaArpRemoteSrvrRowStatus"), ("IPOA-MIB", "ipoaArpRemoteSrvrIpAddr"), ("IPOA-MIB", "ipoaArpRemoteSrvrAdminStatus"), ("IPOA-MIB", "ipoaArpRemoteSrvrOperStatus"),))
if mibBuilder.loadTexts: ipoaLisTableGroup.setDescription('This group is mandatory for all entities which\n          support IP over ATM SVCs.  Support of objects in\n          this group by IP over ATM clients which only\n          support IP over ATM PVCs is optional.')
mibBuilder.exportSymbols("IPOA-MIB", ipoaLisIfMappingTable=ipoaLisIfMappingTable, IpoaVpiInteger=IpoaVpiInteger, ipoaLisCacheEntryAge=ipoaLisCacheEntryAge, ipoaArpClientInArpInvalidOutReqs=ipoaArpClientInArpInvalidOutReqs, ipoaLisCreate=ipoaLisCreate, ipoaArpClientInArpInReqs=ipoaArpClientInArpInReqs, ipoaArpClientInArpOutReplies=ipoaArpClientInArpOutReplies, ipoaLisTableGroup=ipoaLisTableGroup, ipoaArpRemoteSrvrOperStatus=ipoaArpRemoteSrvrOperStatus, ipoaArpSrvrArpUnknownOps=ipoaArpSrvrArpUnknownOps, ipoaArpClientArpOutNaks=ipoaArpClientArpOutNaks, IpoaVciInteger=IpoaVciInteger, ipoaArpRemoteSrvrTable=ipoaArpRemoteSrvrTable, ipoaConfigPvcDefaultMtu=ipoaConfigPvcDefaultMtu, ipoaSrvrNotificationsGroup=ipoaSrvrNotificationsGroup, ipoaArpSrvrArpOutReplies=ipoaArpSrvrArpOutReplies, ipoaArpSrvrInArpInvalidInReqs=ipoaArpSrvrInArpInvalidInReqs, ipoaArpSrvrInArpInReqs=ipoaArpSrvrInArpInReqs, ipoaArpRemoteSrvrIfIndex=ipoaArpRemoteSrvrIfIndex, ipoaArpSrvrTable=ipoaArpSrvrTable, ipoaArpClientArpOutReqs=ipoaArpClientArpOutReqs, ipoaArpClientArpInReplies=ipoaArpClientArpInReplies, ipoaLisIfMappingEntry=ipoaLisIfMappingEntry, ipoaCompliances=ipoaCompliances, ipoaArpClientArpNoSrvrResps=ipoaArpClientArpNoSrvrResps, ipoaArpClientArpUnknownOps=ipoaArpClientArpUnknownOps, ipoaArpClientArpInNaks=ipoaArpClientArpInNaks, ipoaLisDefaultEncapsType=ipoaLisDefaultEncapsType, ipoaLisDelete=ipoaLisDelete, ipoaConfigPvcVci=ipoaConfigPvcVci, ipoaLisDefaultPeakCellRate=ipoaLisDefaultPeakCellRate, ipoaArpClientRowStatus=ipoaArpClientRowStatus, ipoaArpClientArpInReqs=ipoaArpClientArpInReqs, ipoaGroups=ipoaGroups, ipoaGeneralGroup=ipoaGeneralGroup, ipoaArpSrvrArpInReqs=ipoaArpSrvrArpInReqs, IpoaAtmAddr=IpoaAtmAddr, IpoaAtmConnKind=IpoaAtmConnKind, ipoaArpSrvrInArpInReplies=ipoaArpSrvrInArpInReplies, ipoaArpClientEntry=ipoaArpClientEntry, ipoaVcNegotiatedEncapsType=ipoaVcNegotiatedEncapsType, ipoaClientGroup=ipoaClientGroup, ipoaMtuExceeded=ipoaMtuExceeded, ipoaArpClientInArpOutReqs=ipoaArpClientInArpOutReqs, ipoaArpSrvrAddr=ipoaArpSrvrAddr, ipoaArpRemoteSrvrAdminStatus=ipoaArpRemoteSrvrAdminStatus, ipoaArpClientAtmAddr=ipoaArpClientAtmAddr, ipoaVcVci=ipoaVcVci, ipoaNotifications=ipoaNotifications, ipoaArpSrvrArpDupIpAddrs=ipoaArpSrvrArpDupIpAddrs, ipoaConfigPvcIfIndex=ipoaConfigPvcIfIndex, ipoaArpClientArpOutReplies=ipoaArpClientArpOutReplies, ipoaLisTrapEnable=ipoaLisTrapEnable, ipoaConfigPvcVpi=ipoaConfigPvcVpi, PYSNMP_MODULE_ID=ipoaMIB, ipoaLisRowStatus=ipoaLisRowStatus, ipoaArpSrvrLis=ipoaArpSrvrLis, IpoaEncapsType=IpoaEncapsType, ipoaLisQDepth=ipoaLisQDepth, ipoaArpSrvrInArpInvalidOutReqs=ipoaArpSrvrInArpInvalidOutReqs, ipoaSrvrGroup=ipoaSrvrGroup, ipoaLisMaxCalls=ipoaLisMaxCalls, ipoaVcVpi=ipoaVcVpi, ipoaTrapPrefix=ipoaTrapPrefix, ipoaArpClientInArpInvalidInReqs=ipoaArpClientInArpInvalidInReqs, ipoaConfigPvcEntry=ipoaConfigPvcEntry, ipoaLisRetries=ipoaLisRetries, ipoaLisDefaultMtu=ipoaLisDefaultMtu, ipoaArpSrvrEntry=ipoaArpSrvrEntry, ipoaLisIfMappingRowStatus=ipoaLisIfMappingRowStatus, ipoaMIB=ipoaMIB, ipoaConfigPvcTable=ipoaConfigPvcTable, ipoaLisMinHoldingTime=ipoaLisMinHoldingTime, ipoaArpSrvrInArpOutReplies=ipoaArpSrvrInArpOutReplies, ipoaCompliance=ipoaCompliance, ipoaArpSrvrRowStatus=ipoaArpSrvrRowStatus, ipoaArpSrvrInArpOutReqs=ipoaArpSrvrInArpOutReqs, ipoaVcTable=ipoaVcTable, ipoaArpRemoteSrvrIpAddr=ipoaArpRemoteSrvrIpAddr, ipoaLisInactivityTimer=ipoaLisInactivityTimer, ipoaArpRemoteSrvrEntry=ipoaArpRemoteSrvrEntry, ipoaArpClientInArpInReplies=ipoaArpClientInArpInReplies, ipoaArpRemoteSrvrRowStatus=ipoaArpRemoteSrvrRowStatus, ipoaObjects=ipoaObjects, ipoaArpSrvrArpOutNaks=ipoaArpSrvrArpOutNaks, ipoaLisSubnetAddr=ipoaLisSubnetAddr, ipoaConfigPvcRowStatus=ipoaConfigPvcRowStatus, ipoaBasicNotificationsGroup=ipoaBasicNotificationsGroup, ipoaVcEntry=ipoaVcEntry, ipoaVcType=ipoaVcType, ipoaLisIfMappingIfIndex=ipoaLisIfMappingIfIndex, ipoaDuplicateIpAddress=ipoaDuplicateIpAddress, ipoaLisActiveVcs=ipoaLisActiveVcs, ipoaLisTable=ipoaLisTable, ipoaLisTimeout=ipoaLisTimeout, ipoaVcNegotiatedMtu=ipoaVcNegotiatedMtu, ipoaArpClientTable=ipoaArpClientTable, ipoaLisEntry=ipoaLisEntry, ipoaArpRemoteSrvrAtmAddr=ipoaArpRemoteSrvrAtmAddr, ipoaArpClientSrvrInUse=ipoaArpClientSrvrInUse, ipoaLisNotificationsGroup=ipoaLisNotificationsGroup, ipoaConformance=ipoaConformance)



#
# PySNMP MIB module POWER-ETHERNET-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/POWER-ETHERNET-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:24:05 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( softentIND1InLinePower, ) = mibBuilder.importSymbols("ALCATEL-IND1-BASE", "softentIND1InLinePower")
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsIntersection, ValueRangeConstraint, ConstraintsUnion, ValueSizeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsIntersection", "ValueRangeConstraint", "ConstraintsUnion", "ValueSizeConstraint")
( InterfaceIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( Bits, Integer32, Counter64, TimeTicks, IpAddress, Gauge32, MibIdentifier, Unsigned32, MibScalar, MibTable, MibTableRow, MibTableColumn, ObjectIdentity, iso, NotificationType, ModuleIdentity, Counter32, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Bits", "Integer32", "Counter64", "TimeTicks", "IpAddress", "Gauge32", "MibIdentifier", "Unsigned32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "ObjectIdentity", "iso", "NotificationType", "ModuleIdentity", "Counter32")
( TruthValue, DisplayString, TextualConvention, ) = mibBuilder.importSymbols("SNMPv2-TC", "TruthValue", "DisplayString", "TextualConvention")
powerEthernetMIB = ModuleIdentity((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999)).setRevisions(("2002-12-02 00:00",))
if mibBuilder.loadTexts: powerEthernetMIB.setLastUpdated('200212020000Z')
if mibBuilder.loadTexts: powerEthernetMIB.setOrganization('IETF Ethernet Interfaces and Hub MIB\n                         Working Group')
if mibBuilder.loadTexts: powerEthernetMIB.setContactInfo('\n\n                       Chair: Dan Romascanu\n                                  Avaya Inc.\n                                  Tel:  +972-3-645-8414\n                                  Email: dromasca@avaya.com\n\n                       Editor: Avi Berger\n                                 PowerDsine Inc.\n                                   Tel:    972-9-7755100 Ext 307\n                                  Fax:    972-9-7755120\n                                   E-mail: avib@PowerDsine.com\n           ')
if mibBuilder.loadTexts: powerEthernetMIB.setDescription('The MIB module for for managing Powered Devices (PD) or\n                   Power Source Equipment (PSE) working according to the IEEE\n                   802.af Powered Ethernet (DTE Power via MDI) standard.\n                  The following terms are used throughout this\n                  MIB module.  For complete formal definitions,\n                  the IEEE 802.3 standards should be consulted\n                  wherever possible:\n\n                  Group - A recommended, but optional, entity\n                  defined by the IEEE 802.3 management standard,\n                  in order to support a modular numbering scheme.\n                  The classical example allows an implementor to\n                  represent field-replaceable units as groups of\n                  ports, with the port numbering matching the\n                  modular hardware implementation.\n\n                   Port - This entity identifies the port within the group\n                   for which this entry contains information. The numbering\n                   scheme for ports is implementation specific.')
pethNotifications = MibIdentifier((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 0))
pethObjects = MibIdentifier((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1))
pethConformance = MibIdentifier((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 2))
pethPsePortTable = MibTable((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 1), )
if mibBuilder.loadTexts: pethPsePortTable.setDescription('A table of objects that display and control the power\n               characteristics power Ethernet ports on a Power Source\n               Entity (PSE) device. This group will be implemented in\n               managed power Ethernet switches and mid-span devices.')
pethPsePortEntry = MibTableRow((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 1, 1), ).setIndexNames((0, "POWER-ETHERNET-MIB", "pethPsePortGroupIndex"), (0, "POWER-ETHERNET-MIB", "pethPsePortIndex"))
if mibBuilder.loadTexts: pethPsePortEntry.setDescription('A set of objects that display and control the power\n                  characteristics of a power Ethernet PSE port.')
pethPsePortGroupIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: pethPsePortGroupIndex.setDescription('This variable uniquely identifies the group\n               containing the port to which a power Ethernet PSE is connected.\n               Group means box in the stack, module in a rack and the value 1\n               MUST be used for non-modular devices .\n               pethPseMidSpanGroupCapacity is the number of Mid-Span PSE\n               groups that can be contained within the Mid-Span PSE.')
pethPsePortIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: pethPsePortIndex.setDescription('This variable uniquely identifies the power Ethernet PSE\n               port within group pethPseGroupIndex to which the\n               power Ethernet PSE entry is connected.')
pethPsePortAdminEnable = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("enable", 1), ("disable", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pethPsePortAdminEnable.setDescription('Enables power supply on this port.\n            Setting this object at a value enable(1) enables power\n            and detection mechanism for this port.\n            Setting this object at a value disable(2) disables power\n            for this port.')
pethPsePortPowerPairsControlAbility = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 1, 1, 4), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pethPsePortPowerPairsControlAbility.setDescription('Describes the capability of controlling the power pairs\n            functionality to switch pins for sourcing power.\n            The value true indicate that the device has the capability\n            to control the power pairs')
pethPsePortPowerPairs = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 1, 1, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("signal", 1), ("spare", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pethPsePortPowerPairs.setDescription('Describes or controls the pairs in use. If the value of\n            pethPsePortPowerPairsControl is true, this object is\n            writable.\n            A value of signal(1) means that the signal pairs\n            only are in use.\n            A value of spare(2) means that the spare pairs\n            only are in use.')
pethPsePortPowerDetectionControl = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 1, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("auto", 1), ("test", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pethPsePortPowerDetectionControl.setDescription('Controls the power detection mechanism of the port.\n            Setting the value auto(1) enables the power detection\n            mechanism of the port.\n            Setting the value test(2) puts the port in a\n            testmode: force continuous discovery without applying\n            power regardless of whether PD detected.')
pethPsePortDetectionStatus = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 1, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 4, 5, 7, 8,))).clone(namedValues=NamedValues(("disabled", 1), ("searching", 2), ("deliveringPower", 4), ("fault", 5), ("test", 7), ("denyLowPriority", 8),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pethPsePortDetectionStatus.setDescription('Describes the operational status of the port PD detection.\n            A value of disabled(1)- indicates that the PSE State diagram is in\n            the state IDLE\n            A value of searching(2)- indicates that the PSE State diagram is in\n            the state DETECTION, CLASSIFICATION, SIGNATURE_INVALID or BACKOFF.\n            A value of deliveringPower(4) - indicates that the PSE State diagram\n            is in the state POWER_UP, POWER_ON or POWER_OFF.\n            A value of fault(5) - indicates that the PSE State diagram is in the\n            state TEST_ERROR or the state IDLE due to the variable error\n            condition.\n            Faults detected are vendor specific.\n            A value of test(7) - indicates that the PSE State diagram is in the\n            state TEST_MODE.\n            A value of denyLowPriority(8) indicates that the port was\n            disabled by the power management system, in order to keep\n            active higher priority ports.\n             ')
pethPsePortPowerPriority = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 1, 1, 8), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("critical", 1), ("high", 2), ("low", 3),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pethPsePortPowerPriority.setDescription('This object controls the priority of the port from the point\n            of view of a power management algorithm. The priority that\n            is set by this variable could be used by a control mechanism\n            that prevents over current situations by disconnecting first\n            ports with lower power priority. Ports that connect devices\n            critical to the operation of the network - like the E911\n            telephones ports - should be set to higher priority.')
pethPsePortPowerMaintenanceStatus = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 1, 1, 10), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("ok", 1), ("underCurrent", 2), ("mPSAbsent", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pethPsePortPowerMaintenanceStatus.setDescription('The value ok(1) indicates the Power Maintenance\n            Signature is present and the overcurrent condition has not been\n            detected.\n            The value overCurrent (2) indicates an overcurrent condition\n            has been detected.\n            The value mPSAbsent(3) indicates that the Power Maintenance\n            Signature is absent.')
pethPsePortMPSAbsentCounter = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 1, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pethPsePortMPSAbsentCounter.setDescription('Counts the number of times that the\n                pethPsePortPowerMaintenanceStatus attribute changes from any\n                value to the value mPSAbsent(3).')
pethPsePortOverCurrentCounter = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 1, 1, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: pethPsePortOverCurrentCounter.setDescription('Counts the number of times that the aPSEPowerCurrentStatus\n                 attribute changes from any value to the value overCurrent(2).')
pethPsePortType = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 1, 1, 13), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("other", 1), ("telephone", 2), ("webcam", 3), ("wireless", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pethPsePortType.setDescription('A manager will set the value of this variable to a value\n            that indicates the type of the device that is connected\n            to theport. This value can be the result of the mapping\n            the address of the station connected to the port and of\n            the value of the pethPdPortType of the respective PD port.')
pethPsePortPowerClassifications = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 1, 1, 14), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("class0", 1), ("class1", 2), ("class2", 3), ("class3", 4), ("class4", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pethPsePortPowerClassifications.setDescription('Classification is a way to tag different terminals on the\n           Power over LAN network according to their power consumption.\n           Devices such as IP telephones, WLAN access points and others,\n           will be classified according to their power requirements.\n\n          The value is only valid while a valid PD is being detected as\n          indicated by the attribute pethPsePortDetectionStatus reporting\n          the value or deliveringPower(4).')
pethPdPortTable = MibTable((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 2), )
if mibBuilder.loadTexts: pethPdPortTable.setDescription('A table of objects that display and control the power\n               characteristics power Ethernet ports on a Powered\n               Device(PD) device. This group will be implemented in\n               managed powered and mid-span devices.')
pethPdPortEntry = MibTableRow((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 2, 1), ).setIndexNames((0, "POWER-ETHERNET-MIB", "pethPdPortIndex"))
if mibBuilder.loadTexts: pethPdPortEntry.setDescription('A set of objects that display and control the power\n               characteristics of a Powered Device port.')
pethPdPortIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 2, 1, 1), InterfaceIndex())
if mibBuilder.loadTexts: pethPdPortIndex.setDescription('An index value that uniquely identifies an\n               interface to a PD device.  The\n               interface identified by a particular value of\n               this index is the same interface as identified\n               by the same value of ifIndex. The mapping\n               between the ifIndex values and the numbering of\n               the port on the device is an implementation\n               issue.')
pethPdPortAdminEnable = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 2, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("enable", 1), ("disable", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pethPdPortAdminEnable.setDescription('This value  identifies the operational state of the PD functions.\n                 An interface which can provide the PD functions will be enabled\n                 to do so when this attribute has the value enable. When this\n                 attribute has the value disable the interface will act\n                 as it would if it had no PD function.')
pethMainPseObjects = MibIdentifier((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 3))
pethMainPseTable = MibTable((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 3, 1), )
if mibBuilder.loadTexts: pethMainPseTable.setDescription("A table of objects that display and control the Main power\n             on a PSE  device. Example - an Ethernet switch midspan device can\n               control an Ethnternet port and the Main Power supply unit's.")
pethMainPseEntry = MibTableRow((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 3, 1, 1), ).setIndexNames((0, "POWER-ETHERNET-MIB", "pethMainPseGroupIndex"))
if mibBuilder.loadTexts: pethMainPseEntry.setDescription('A set of objects that display and control the Main power\n                of a PSE. ')
pethMainPseGroupIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 3, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: pethMainPseGroupIndex.setDescription('This variable uniquely identifies the group to which\n              power Ethernet PSE is connected.Group means (box in the stack,\n              module in a rack) and  the value 1 MUST be  used for non-modular\n              devices ')
pethMainPsePower = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 3, 1, 1, 2), Gauge32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setUnits('Watts').setMaxAccess("readonly")
if mibBuilder.loadTexts: pethMainPsePower.setDescription('The nominal power of the PSE expressed in Watts.')
pethMainPseOperStatus = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 3, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("on", 1), ("off", 2), ("faulty", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: pethMainPseOperStatus.setDescription('The operational status of the main PSE.')
pethMainPseConsumptionPower = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 3, 1, 1, 4), Gauge32()).setUnits('Watts').setMaxAccess("readonly")
if mibBuilder.loadTexts: pethMainPseConsumptionPower.setDescription('Measured usage power expressed in Watts.')
pethMainPseUsageThreshold = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 3, 1, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,99))).setUnits('%').setMaxAccess("readwrite")
if mibBuilder.loadTexts: pethMainPseUsageThreshold.setDescription('The usage threshold expressed in percents for\n                   comparing the measured power and initiating\n                   an alarm if the threshold is exceeded.')
pethNotificationControl = MibIdentifier((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 4))
pethNotificationControlTable = MibTable((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 4, 1), )
if mibBuilder.loadTexts: pethNotificationControlTable.setDescription('A table of objects that display and control the Notification\n             on a PSE  device.')
pethNotificationControlEntry = MibTableRow((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 4, 1, 1), ).setIndexNames((0, "POWER-ETHERNET-MIB", "pethNotificationControlGroupIndex"))
if mibBuilder.loadTexts: pethNotificationControlEntry.setDescription('A set of objects that control the Notification events.')
pethNotificationControlGroupIndex = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 4, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: pethNotificationControlGroupIndex.setDescription('This variable uniquely identifies the group. Group means\n              box in the stack, module in a rack and it is RECOMENDED\n              that the value 1 be used for non-modular devices ')
pethNotificationControlEnable = MibTableColumn((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 1, 4, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("enable", 1), ("disable", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: pethNotificationControlEnable.setDescription('Enable Notification from Agent')
pethPsePortOnOffNotification = NotificationType((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 0, 1)).setObjects(*(("POWER-ETHERNET-MIB", "pethPsePortDetectionStatus"),))
if mibBuilder.loadTexts: pethPsePortOnOffNotification.setDescription(' This Notification indicates if Pse Port is  delivering  or\n                       not power to the PD. This Notification SHOULD be sent on\n                       every status change except in the searching mode.')
pethPsePortPowerMaintenanceStatusNotification = NotificationType((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 0, 2)).setObjects(*(("POWER-ETHERNET-MIB", "pethPsePortPowerMaintenanceStatus"),))
if mibBuilder.loadTexts: pethPsePortPowerMaintenanceStatusNotification.setDescription(' This Notification indicates a Port Change Status and it\n                        SHOULD be sent on every status change.')
pethMainPowerUsageOnNotification = NotificationType((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 0, 4)).setObjects(*(("POWER-ETHERNET-MIB", "pethMainPseConsumptionPower"),))
if mibBuilder.loadTexts: pethMainPowerUsageOnNotification.setDescription(' This Notification indicate PSE Threshold usage indication is\n                       on, the usage power is above the threshold.')
pethMainPowerUsageOffNotification = NotificationType((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 0, 5)).setObjects(*(("POWER-ETHERNET-MIB", "pethMainPseConsumptionPower"),))
if mibBuilder.loadTexts: pethMainPowerUsageOffNotification.setDescription(' This Notification indicate PSE Threshold usage indication\n                       off, the usage power is below the threshold.')
pethCompliances = MibIdentifier((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 2, 1))
pethGroups = MibIdentifier((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 2, 2))
pethCompliance = ModuleCompliance((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 2, 1, 1)).setObjects(*(("POWER-ETHERNET-MIB", "pethPsePortGroup"), ("POWER-ETHERNET-MIB", "pethPdPortGroup"), ("POWER-ETHERNET-MIB", "pethMainPseGroup"), ("POWER-ETHERNET-MIB", "pethNotificationControlGroup"),))
if mibBuilder.loadTexts: pethCompliance.setDescription('Describes the requirements for conformance to the\n               Power Ethernet MIB.')
pethPseCompliance = ModuleCompliance((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 2, 1, 2)).setObjects(*(("POWER-ETHERNET-MIB", "pethPsePortGroup"), ("POWER-ETHERNET-MIB", "pethMainPseGroup"), ("POWER-ETHERNET-MIB", "pethNotificationControlGroup"),))
if mibBuilder.loadTexts: pethPseCompliance.setDescription('Describes the requirements for conformance to the PSE and MID-\n                Span.')
pethPdCompliance = ModuleCompliance((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 2, 1, 3)).setObjects(*(("POWER-ETHERNET-MIB", "pethPdPortGroup"),))
if mibBuilder.loadTexts: pethPdCompliance.setDescription('Describes the requirements for conformance to the PD.')
pethPsePortGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 2, 2, 1)).setObjects(*(("POWER-ETHERNET-MIB", "pethPsePortAdminEnable"), ("POWER-ETHERNET-MIB", "pethPsePortPowerPairsControlAbility"), ("POWER-ETHERNET-MIB", "pethPsePortPowerDetectionControl"), ("POWER-ETHERNET-MIB", "pethPsePortPowerPairs"), ("POWER-ETHERNET-MIB", "pethPsePortDetectionStatus"), ("POWER-ETHERNET-MIB", "pethPsePortPowerPriority"), ("POWER-ETHERNET-MIB", "pethPsePortPowerMaintenanceStatus"), ("POWER-ETHERNET-MIB", "pethPsePortMPSAbsentCounter"), ("POWER-ETHERNET-MIB", "pethPsePortOverCurrentCounter"), ("POWER-ETHERNET-MIB", "pethPsePortType"), ("POWER-ETHERNET-MIB", "pethPsePortPowerClassifications"),))
if mibBuilder.loadTexts: pethPsePortGroup.setDescription('The pethPsePortGroup is mandatory for systems which\n             implement PSE ports.')
pethPdPortGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 2, 2, 2)).setObjects(*(("POWER-ETHERNET-MIB", "pethPdPortAdminEnable"),))
if mibBuilder.loadTexts: pethPdPortGroup.setDescription('The pethPdPortGroup is mandatory for systems which\n        implement PD Ports.')
pethMainPseGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 2, 2, 3)).setObjects(*(("POWER-ETHERNET-MIB", "pethMainPsePower"), ("POWER-ETHERNET-MIB", "pethMainPseOperStatus"), ("POWER-ETHERNET-MIB", "pethMainPseConsumptionPower"), ("POWER-ETHERNET-MIB", "pethMainPseUsageThreshold"),))
if mibBuilder.loadTexts: pethMainPseGroup.setDescription('Main PSE Objects. ')
pethNotificationControlGroup = ObjectGroup((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 2, 2, 4)).setObjects(*(("POWER-ETHERNET-MIB", "pethNotificationControlEnable"),))
if mibBuilder.loadTexts: pethNotificationControlGroup.setDescription('Notification Control  Objects. ')
pethPsePortNotificationGroup = NotificationGroup((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 2, 1, 4)).setObjects(*(("POWER-ETHERNET-MIB", "pethPsePortOnOffNotification"), ("POWER-ETHERNET-MIB", "pethPsePortPowerMaintenanceStatusNotification"),))
if mibBuilder.loadTexts: pethPsePortNotificationGroup.setDescription('Pse Notification indications')
pethMainPowerNotificationGroup = NotificationGroup((1, 3, 6, 1, 4, 1, 6486, 800, 1, 2, 1, 27, 999, 2, 1, 5)).setObjects(*(("POWER-ETHERNET-MIB", "pethMainPowerUsageOnNotification"), ("POWER-ETHERNET-MIB", "pethMainPowerUsageOffNotification"),))
if mibBuilder.loadTexts: pethMainPowerNotificationGroup.setDescription('Pse Notification indications')
mibBuilder.exportSymbols("POWER-ETHERNET-MIB", pethPdPortAdminEnable=pethPdPortAdminEnable, pethPsePortMPSAbsentCounter=pethPsePortMPSAbsentCounter, pethPsePortIndex=pethPsePortIndex, pethMainPseTable=pethMainPseTable, pethPsePortOnOffNotification=pethPsePortOnOffNotification, pethPdPortTable=pethPdPortTable, pethMainPseObjects=pethMainPseObjects, pethMainPseConsumptionPower=pethMainPseConsumptionPower, pethConformance=pethConformance, pethPsePortPowerClassifications=pethPsePortPowerClassifications, pethNotificationControl=pethNotificationControl, pethNotificationControlEnable=pethNotificationControlEnable, pethMainPseGroupIndex=pethMainPseGroupIndex, pethPdPortIndex=pethPdPortIndex, pethNotificationControlGroup=pethNotificationControlGroup, pethPsePortGroup=pethPsePortGroup, pethPsePortAdminEnable=pethPsePortAdminEnable, pethPsePortPowerMaintenanceStatusNotification=pethPsePortPowerMaintenanceStatusNotification, pethPsePortPowerDetectionControl=pethPsePortPowerDetectionControl, PYSNMP_MODULE_ID=powerEthernetMIB, pethPsePortType=pethPsePortType, pethNotificationControlGroupIndex=pethNotificationControlGroupIndex, pethMainPowerUsageOnNotification=pethMainPowerUsageOnNotification, pethPdPortEntry=pethPdPortEntry, pethCompliance=pethCompliance, pethPseCompliance=pethPseCompliance, pethObjects=pethObjects, pethPdPortGroup=pethPdPortGroup, pethPsePortPowerMaintenanceStatus=pethPsePortPowerMaintenanceStatus, pethPdCompliance=pethPdCompliance, pethPsePortTable=pethPsePortTable, powerEthernetMIB=powerEthernetMIB, pethPsePortNotificationGroup=pethPsePortNotificationGroup, pethMainPowerNotificationGroup=pethMainPowerNotificationGroup, pethPsePortPowerPairs=pethPsePortPowerPairs, pethNotificationControlTable=pethNotificationControlTable, pethGroups=pethGroups, pethPsePortOverCurrentCounter=pethPsePortOverCurrentCounter, pethMainPseOperStatus=pethMainPseOperStatus, pethPsePortGroupIndex=pethPsePortGroupIndex, pethPsePortEntry=pethPsePortEntry, pethMainPsePower=pethMainPsePower, pethPsePortDetectionStatus=pethPsePortDetectionStatus, pethNotificationControlEntry=pethNotificationControlEntry, pethMainPseEntry=pethMainPseEntry, pethMainPseGroup=pethMainPseGroup, pethPsePortPowerPairsControlAbility=pethPsePortPowerPairsControlAbility, pethCompliances=pethCompliances, pethNotifications=pethNotifications, pethPsePortPowerPriority=pethPsePortPowerPriority, pethMainPowerUsageOffNotification=pethMainPowerUsageOffNotification, pethMainPseUsageThreshold=pethMainPseUsageThreshold)



#
# PySNMP MIB module TCP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/TCP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:31:06 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( Integer, ObjectIdentifier, OctetString, ) = mibBuilder.importSymbols("ASN1", "Integer", "ObjectIdentifier", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ValueSizeConstraint, ConstraintsUnion, ConstraintsIntersection, SingleValueConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsUnion", "ConstraintsIntersection", "SingleValueConstraint")
( InetAddressType, InetAddress, InetPortNumber, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetAddressType", "InetAddress", "InetPortNumber")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( MibScalar, MibTable, MibTableRow, MibTableColumn, MibIdentifier, mib_2, Integer32, ModuleIdentity, IpAddress, Bits, ObjectIdentity, iso, Counter64, Gauge32, NotificationType, Counter32, Unsigned32, TimeTicks, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "MibIdentifier", "mib-2", "Integer32", "ModuleIdentity", "IpAddress", "Bits", "ObjectIdentity", "iso", "Counter64", "Gauge32", "NotificationType", "Counter32", "Unsigned32", "TimeTicks")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
tcpMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 49)).setRevisions(("2005-02-18 00:00", "1994-11-01 00:00", "1991-03-31 00:00",))
if mibBuilder.loadTexts: tcpMIB.setLastUpdated('200502180000Z')
if mibBuilder.loadTexts: tcpMIB.setOrganization('IETF IPv6 MIB Revision Team\n            http://www.ietf.org/html.charters/ipv6-charter.html')
if mibBuilder.loadTexts: tcpMIB.setContactInfo('Rajiv Raghunarayan (editor)\n\n            Cisco Systems Inc.\n            170 West Tasman Drive\n            San Jose, CA 95134\n\n            Phone: +1 408 853 9612\n            Email: <raraghun@cisco.com>\n\n            Send comments to <ipv6@ietf.org>')
if mibBuilder.loadTexts: tcpMIB.setDescription('The MIB module for managing TCP implementations.\n\n            Copyright (C) The Internet Society (2005). This version\n            of this MIB module is a part of RFC 4022; see the RFC\n            itself for full legal notices.')
tcp = MibIdentifier((1, 3, 6, 1, 2, 1, 6))
tcpRtoAlgorithm = MibScalar((1, 3, 6, 1, 2, 1, 6, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))).clone(namedValues=NamedValues(("other", 1), ("constant", 2), ("rsre", 3), ("vanj", 4), ("rfc2988", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpRtoAlgorithm.setDescription('The algorithm used to determine the timeout value used for\n            retransmitting unacknowledged octets.')
tcpRtoMin = MibScalar((1, 3, 6, 1, 2, 1, 6, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpRtoMin.setDescription('The minimum value permitted by a TCP implementation for\n            the retransmission timeout, measured in milliseconds.\n            More refined semantics for objects of this type depend\n            on the algorithm used to determine the retransmission\n            timeout; in particular, the IETF standard algorithm\n            rfc2988(5) provides a minimum value.')
tcpRtoMax = MibScalar((1, 3, 6, 1, 2, 1, 6, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpRtoMax.setDescription('The maximum value permitted by a TCP implementation for\n            the retransmission timeout, measured in milliseconds.\n            More refined semantics for objects of this type depend\n            on the algorithm used to determine the retransmission\n            timeout; in particular, the IETF standard algorithm\n            rfc2988(5) provides an upper bound (as part of an\n            adaptive backoff algorithm).')
tcpMaxConn = MibScalar((1, 3, 6, 1, 2, 1, 6, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(-1,-1),ValueRangeConstraint(0,2147483647),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpMaxConn.setDescription('The limit on the total number of TCP connections the entity\n            can support.  In entities where the maximum number of\n            connections is dynamic, this object should contain the\n            value -1.')
tcpActiveOpens = MibScalar((1, 3, 6, 1, 2, 1, 6, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpActiveOpens.setDescription('The number of times that TCP connections have made a direct\n            transition to the SYN-SENT state from the CLOSED state.\n\n            Discontinuities in the value of this counter are\n            indicated via discontinuities in the value of sysUpTime.')
tcpPassiveOpens = MibScalar((1, 3, 6, 1, 2, 1, 6, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpPassiveOpens.setDescription('The number of times TCP connections have made a direct\n            transition to the SYN-RCVD state from the LISTEN state.\n\n            Discontinuities in the value of this counter are\n            indicated via discontinuities in the value of sysUpTime.')
tcpAttemptFails = MibScalar((1, 3, 6, 1, 2, 1, 6, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpAttemptFails.setDescription('The number of times that TCP connections have made a direct\n            transition to the CLOSED state from either the SYN-SENT\n            state or the SYN-RCVD state, plus the number of times that\n            TCP connections have made a direct transition to the\n            LISTEN state from the SYN-RCVD state.\n\n            Discontinuities in the value of this counter are\n            indicated via discontinuities in the value of sysUpTime.')
tcpEstabResets = MibScalar((1, 3, 6, 1, 2, 1, 6, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpEstabResets.setDescription('The number of times that TCP connections have made a direct\n            transition to the CLOSED state from either the ESTABLISHED\n            state or the CLOSE-WAIT state.\n\n            Discontinuities in the value of this counter are\n            indicated via discontinuities in the value of sysUpTime.')
tcpCurrEstab = MibScalar((1, 3, 6, 1, 2, 1, 6, 9), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpCurrEstab.setDescription('The number of TCP connections for which the current state\n            is either ESTABLISHED or CLOSE-WAIT.')
tcpInSegs = MibScalar((1, 3, 6, 1, 2, 1, 6, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpInSegs.setDescription('The total number of segments received, including those\n            received in error.  This count includes segments received\n            on currently established connections.\n\n            Discontinuities in the value of this counter are\n            indicated via discontinuities in the value of sysUpTime.')
tcpOutSegs = MibScalar((1, 3, 6, 1, 2, 1, 6, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpOutSegs.setDescription('The total number of segments sent, including those on\n            current connections but excluding those containing only\n            retransmitted octets.\n\n            Discontinuities in the value of this counter are\n            indicated via discontinuities in the value of sysUpTime.')
tcpRetransSegs = MibScalar((1, 3, 6, 1, 2, 1, 6, 12), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpRetransSegs.setDescription('The total number of segments retransmitted; that is, the\n            number of TCP segments transmitted containing one or more\n            previously transmitted octets.\n\n            Discontinuities in the value of this counter are\n            indicated via discontinuities in the value of sysUpTime.')
tcpInErrs = MibScalar((1, 3, 6, 1, 2, 1, 6, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpInErrs.setDescription('The total number of segments received in error (e.g., bad\n            TCP checksums).\n\n            Discontinuities in the value of this counter are\n            indicated via discontinuities in the value of sysUpTime.')
tcpOutRsts = MibScalar((1, 3, 6, 1, 2, 1, 6, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpOutRsts.setDescription('The number of TCP segments sent containing the RST flag.\n\n            Discontinuities in the value of this counter are\n            indicated via discontinuities in the value of sysUpTime.')
tcpHCInSegs = MibScalar((1, 3, 6, 1, 2, 1, 6, 17), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpHCInSegs.setDescription('The total number of segments received, including those\n            received in error.  This count includes segments received\n\n            on currently established connections.  This object is\n            the 64-bit equivalent of tcpInSegs.\n\n            Discontinuities in the value of this counter are\n            indicated via discontinuities in the value of sysUpTime.')
tcpHCOutSegs = MibScalar((1, 3, 6, 1, 2, 1, 6, 18), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpHCOutSegs.setDescription('The total number of segments sent, including those on\n            current connections but excluding those containing only\n            retransmitted octets.  This object is the 64-bit\n            equivalent of tcpOutSegs.\n\n            Discontinuities in the value of this counter are\n            indicated via discontinuities in the value of sysUpTime.')
tcpConnectionTable = MibTable((1, 3, 6, 1, 2, 1, 6, 19), )
if mibBuilder.loadTexts: tcpConnectionTable.setDescription('A table containing information about existing TCP\n            connections.  Note that unlike earlier TCP MIBs, there\n            is a separate table for connections in the LISTEN state.')
tcpConnectionEntry = MibTableRow((1, 3, 6, 1, 2, 1, 6, 19, 1), ).setIndexNames((0, "TCP-MIB", "tcpConnectionLocalAddressType"), (0, "TCP-MIB", "tcpConnectionLocalAddress"), (0, "TCP-MIB", "tcpConnectionLocalPort"), (0, "TCP-MIB", "tcpConnectionRemAddressType"), (0, "TCP-MIB", "tcpConnectionRemAddress"), (0, "TCP-MIB", "tcpConnectionRemPort"))
if mibBuilder.loadTexts: tcpConnectionEntry.setDescription('A conceptual row of the tcpConnectionTable containing\n            information about a particular current TCP connection.\n            Each row of this table is transient in that it ceases to\n            exist when (or soon after) the connection makes the\n            transition to the CLOSED state.')
tcpConnectionLocalAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 19, 1, 1), InetAddressType())
if mibBuilder.loadTexts: tcpConnectionLocalAddressType.setDescription('The address type of tcpConnectionLocalAddress.')
tcpConnectionLocalAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 19, 1, 2), InetAddress())
if mibBuilder.loadTexts: tcpConnectionLocalAddress.setDescription('The local IP address for this TCP connection.  The type\n            of this address is determined by the value of\n            tcpConnectionLocalAddressType.\n\n            As this object is used in the index for the\n            tcpConnectionTable, implementors should be\n            careful not to create entries that would result in OIDs\n            with more than 128 subidentifiers; otherwise the information\n            cannot be accessed by using SNMPv1, SNMPv2c, or SNMPv3.')
tcpConnectionLocalPort = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 19, 1, 3), InetPortNumber())
if mibBuilder.loadTexts: tcpConnectionLocalPort.setDescription('The local port number for this TCP connection.')
tcpConnectionRemAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 19, 1, 4), InetAddressType())
if mibBuilder.loadTexts: tcpConnectionRemAddressType.setDescription('The address type of tcpConnectionRemAddress.')
tcpConnectionRemAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 19, 1, 5), InetAddress())
if mibBuilder.loadTexts: tcpConnectionRemAddress.setDescription('The remote IP address for this TCP connection.  The type\n            of this address is determined by the value of\n            tcpConnectionRemAddressType.\n\n            As this object is used in the index for the\n            tcpConnectionTable, implementors should be\n            careful not to create entries that would result in OIDs\n            with more than 128 subidentifiers; otherwise the information\n            cannot be accessed by using SNMPv1, SNMPv2c, or SNMPv3.')
tcpConnectionRemPort = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 19, 1, 6), InetPortNumber())
if mibBuilder.loadTexts: tcpConnectionRemPort.setDescription('The remote port number for this TCP connection.')
tcpConnectionState = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 19, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,))).clone(namedValues=NamedValues(("closed", 1), ("listen", 2), ("synSent", 3), ("synReceived", 4), ("established", 5), ("finWait1", 6), ("finWait2", 7), ("closeWait", 8), ("lastAck", 9), ("closing", 10), ("timeWait", 11), ("deleteTCB", 12),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: tcpConnectionState.setDescription("The state of this TCP connection.\n\n            The value listen(2) is included only for parallelism to the\n            old tcpConnTable and should not be used.  A connection in\n            LISTEN state should be present in the tcpListenerTable.\n\n            The only value that may be set by a management station is\n            deleteTCB(12).  Accordingly, it is appropriate for an agent\n            to return a `badValue' response if a management station\n            attempts to set this object to any other value.\n\n            If a management station sets this object to the value\n            deleteTCB(12), then the TCB (as defined in [RFC793]) of\n            the corresponding connection on the managed node is\n            deleted, resulting in immediate termination of the\n            connection.\n\n            As an implementation-specific option, a RST segment may be\n            sent from the managed node to the other TCP endpoint (note,\n            however, that RST segments are not sent reliably).")
tcpConnectionProcess = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 19, 1, 8), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpConnectionProcess.setDescription("The system's process ID for the process associated with\n            this connection, or zero if there is no such process.  This\n            value is expected to be the same as HOST-RESOURCES-MIB::\n            hrSWRunIndex or SYSAPPL-MIB::sysApplElmtRunIndex for some\n            row in the appropriate tables.")
tcpListenerTable = MibTable((1, 3, 6, 1, 2, 1, 6, 20), )
if mibBuilder.loadTexts: tcpListenerTable.setDescription("A table containing information about TCP listeners.  A\n            listening application can be represented in three\n            possible ways:\n\n            1. An application that is willing to accept both IPv4 and\n               IPv6 datagrams is represented by\n\n               a tcpListenerLocalAddressType of unknown (0) and\n               a tcpListenerLocalAddress of ''h (a zero-length\n               octet-string).\n\n            2. An application that is willing to accept only IPv4 or\n               IPv6 datagrams is represented by a\n               tcpListenerLocalAddressType of the appropriate address\n               type and a tcpListenerLocalAddress of '0.0.0.0' or '::'\n               respectively.\n\n            3. An application that is listening for data destined\n               only to a specific IP address, but from any remote\n               system, is represented by a tcpListenerLocalAddressType\n               of an appropriate address type, with\n               tcpListenerLocalAddress as the specific local address.\n\n            NOTE: The address type in this table represents the\n            address type used for the communication, irrespective\n            of the higher-layer abstraction.  For example, an\n            application using IPv6 'sockets' to communicate via\n            IPv4 between ::ffff:10.0.0.1 and ::ffff:10.0.0.2 would\n            use InetAddressType ipv4(1)).")
tcpListenerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 6, 20, 1), ).setIndexNames((0, "TCP-MIB", "tcpListenerLocalAddressType"), (0, "TCP-MIB", "tcpListenerLocalAddress"), (0, "TCP-MIB", "tcpListenerLocalPort"))
if mibBuilder.loadTexts: tcpListenerEntry.setDescription('A conceptual row of the tcpListenerTable containing\n            information about a particular TCP listener.')
tcpListenerLocalAddressType = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 20, 1, 1), InetAddressType())
if mibBuilder.loadTexts: tcpListenerLocalAddressType.setDescription('The address type of tcpListenerLocalAddress.  The value\n            should be unknown (0) if connection initiations to all\n            local IP addresses are accepted.')
tcpListenerLocalAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 20, 1, 2), InetAddress())
if mibBuilder.loadTexts: tcpListenerLocalAddress.setDescription("The local IP address for this TCP connection.\n\n            The value of this object can be represented in three\n            possible ways, depending on the characteristics of the\n            listening application:\n\n            1. For an application willing to accept both IPv4 and\n               IPv6 datagrams, the value of this object must be\n               ''h (a zero-length octet-string), with the value\n               of the corresponding tcpListenerLocalAddressType\n               object being unknown (0).\n\n            2. For an application willing to accept only IPv4 or\n               IPv6 datagrams, the value of this object must be\n               '0.0.0.0' or '::' respectively, with\n               tcpListenerLocalAddressType representing the\n               appropriate address type.\n\n            3. For an application which is listening for data\n               destined only to a specific IP address, the value\n               of this object is the specific local address, with\n               tcpListenerLocalAddressType representing the\n               appropriate address type.\n\n            As this object is used in the index for the\n            tcpListenerTable, implementors should be\n            careful not to create entries that would result in OIDs\n            with more than 128 subidentifiers; otherwise the information\n            cannot be accessed, using SNMPv1, SNMPv2c, or SNMPv3.")
tcpListenerLocalPort = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 20, 1, 3), InetPortNumber())
if mibBuilder.loadTexts: tcpListenerLocalPort.setDescription('The local port number for this TCP connection.')
tcpListenerProcess = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 20, 1, 4), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpListenerProcess.setDescription("The system's process ID for the process associated with\n            this listener, or zero if there is no such process.  This\n            value is expected to be the same as HOST-RESOURCES-MIB::\n            hrSWRunIndex or SYSAPPL-MIB::sysApplElmtRunIndex for some\n            row in the appropriate tables.")
tcpConnTable = MibTable((1, 3, 6, 1, 2, 1, 6, 13), )
if mibBuilder.loadTexts: tcpConnTable.setDescription('A table containing information about existing IPv4-specific\n            TCP connections or listeners.  This table has been\n            deprecated in favor of the version neutral\n            tcpConnectionTable.')
tcpConnEntry = MibTableRow((1, 3, 6, 1, 2, 1, 6, 13, 1), ).setIndexNames((0, "TCP-MIB", "tcpConnLocalAddress"), (0, "TCP-MIB", "tcpConnLocalPort"), (0, "TCP-MIB", "tcpConnRemAddress"), (0, "TCP-MIB", "tcpConnRemPort"))
if mibBuilder.loadTexts: tcpConnEntry.setDescription('A conceptual row of the tcpConnTable containing information\n            about a particular current IPv4 TCP connection.  Each row\n            of this table is transient in that it ceases to exist when\n            (or soon after) the connection makes the transition to the\n            CLOSED state.')
tcpConnState = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 13, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,))).clone(namedValues=NamedValues(("closed", 1), ("listen", 2), ("synSent", 3), ("synReceived", 4), ("established", 5), ("finWait1", 6), ("finWait2", 7), ("closeWait", 8), ("lastAck", 9), ("closing", 10), ("timeWait", 11), ("deleteTCB", 12),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: tcpConnState.setDescription("The state of this TCP connection.\n\n            The only value that may be set by a management station is\n            deleteTCB(12).  Accordingly, it is appropriate for an agent\n            to return a `badValue' response if a management station\n            attempts to set this object to any other value.\n\n            If a management station sets this object to the value\n            deleteTCB(12), then the TCB (as defined in [RFC793]) of\n            the corresponding connection on the managed node is\n            deleted, resulting in immediate termination of the\n            connection.\n\n            As an implementation-specific option, a RST segment may be\n            sent from the managed node to the other TCP endpoint (note,\n            however, that RST segments are not sent reliably).")
tcpConnLocalAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 13, 1, 2), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpConnLocalAddress.setDescription('The local IP address for this TCP connection.  In the case\n            of a connection in the listen state willing to\n            accept connections for any IP interface associated with the\n            node, the value 0.0.0.0 is used.')
tcpConnLocalPort = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 13, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpConnLocalPort.setDescription('The local port number for this TCP connection.')
tcpConnRemAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 13, 1, 4), IpAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpConnRemAddress.setDescription('The remote IP address for this TCP connection.')
tcpConnRemPort = MibTableColumn((1, 3, 6, 1, 2, 1, 6, 13, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: tcpConnRemPort.setDescription('The remote port number for this TCP connection.')
tcpMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 49, 2))
tcpMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 49, 2, 1))
tcpMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 49, 2, 2))
tcpMIBCompliance2 = ModuleCompliance((1, 3, 6, 1, 2, 1, 49, 2, 1, 2)).setObjects(*(("TCP-MIB", "tcpBaseGroup"), ("TCP-MIB", "tcpConnectionGroup"), ("TCP-MIB", "tcpListenerGroup"), ("TCP-MIB", "tcpHCGroup"),))
if mibBuilder.loadTexts: tcpMIBCompliance2.setDescription('The compliance statement for systems that implement TCP.\n\n            A number of INDEX objects cannot be\n            represented in the form of OBJECT clauses in SMIv2 but\n            have the following compliance requirements,\n            expressed in OBJECT clause form in this description\n            clause:\n\n            -- OBJECT      tcpConnectionLocalAddressType\n            -- SYNTAX      InetAddressType { ipv4(1), ipv6(2) }\n            -- DESCRIPTION\n            --     This MIB requires support for only global IPv4\n\n            --     and IPv6 address types.\n            --\n            -- OBJECT      tcpConnectionRemAddressType\n            -- SYNTAX      InetAddressType { ipv4(1), ipv6(2) }\n            -- DESCRIPTION\n            --     This MIB requires support for only global IPv4\n            --     and IPv6 address types.\n            --\n            -- OBJECT      tcpListenerLocalAddressType\n            -- SYNTAX      InetAddressType { unknown(0), ipv4(1),\n            --                               ipv6(2) }\n            -- DESCRIPTION\n            --     This MIB requires support for only global IPv4\n            --     and IPv6 address types.  The type unknown also\n            --     needs to be supported to identify a special\n            --     case in the listener table: a listen using\n            --     both IPv4 and IPv6 addresses on the device.\n            --\n           ')
tcpMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 49, 2, 1, 1)).setObjects(*(("TCP-MIB", "tcpGroup"),))
if mibBuilder.loadTexts: tcpMIBCompliance.setDescription('The compliance statement for IPv4-only systems that\n            implement TCP.  In order to be IP version independent, this\n            compliance statement is deprecated in favor of\n            tcpMIBCompliance2.  However, agents are still encouraged\n            to implement these objects in order to interoperate with\n            the deployed base of managers.')
tcpGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 49, 2, 2, 1)).setObjects(*(("TCP-MIB", "tcpRtoAlgorithm"), ("TCP-MIB", "tcpRtoMin"), ("TCP-MIB", "tcpRtoMax"), ("TCP-MIB", "tcpMaxConn"), ("TCP-MIB", "tcpActiveOpens"), ("TCP-MIB", "tcpPassiveOpens"), ("TCP-MIB", "tcpAttemptFails"), ("TCP-MIB", "tcpEstabResets"), ("TCP-MIB", "tcpCurrEstab"), ("TCP-MIB", "tcpInSegs"), ("TCP-MIB", "tcpOutSegs"), ("TCP-MIB", "tcpRetransSegs"), ("TCP-MIB", "tcpConnState"), ("TCP-MIB", "tcpConnLocalAddress"), ("TCP-MIB", "tcpConnLocalPort"), ("TCP-MIB", "tcpConnRemAddress"), ("TCP-MIB", "tcpConnRemPort"), ("TCP-MIB", "tcpInErrs"), ("TCP-MIB", "tcpOutRsts"),))
if mibBuilder.loadTexts: tcpGroup.setDescription('The tcp group of objects providing for management of TCP\n            entities.')
tcpBaseGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 49, 2, 2, 2)).setObjects(*(("TCP-MIB", "tcpRtoAlgorithm"), ("TCP-MIB", "tcpRtoMin"), ("TCP-MIB", "tcpRtoMax"), ("TCP-MIB", "tcpMaxConn"), ("TCP-MIB", "tcpActiveOpens"), ("TCP-MIB", "tcpPassiveOpens"), ("TCP-MIB", "tcpAttemptFails"), ("TCP-MIB", "tcpEstabResets"), ("TCP-MIB", "tcpCurrEstab"), ("TCP-MIB", "tcpInSegs"), ("TCP-MIB", "tcpOutSegs"), ("TCP-MIB", "tcpRetransSegs"), ("TCP-MIB", "tcpInErrs"), ("TCP-MIB", "tcpOutRsts"),))
if mibBuilder.loadTexts: tcpBaseGroup.setDescription('The group of counters common to TCP entities.')
tcpConnectionGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 49, 2, 2, 3)).setObjects(*(("TCP-MIB", "tcpConnectionState"), ("TCP-MIB", "tcpConnectionProcess"),))
if mibBuilder.loadTexts: tcpConnectionGroup.setDescription('The group provides general information about TCP\n            connections.')
tcpListenerGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 49, 2, 2, 4)).setObjects(*(("TCP-MIB", "tcpListenerProcess"),))
if mibBuilder.loadTexts: tcpListenerGroup.setDescription('This group has objects providing general information about\n            TCP listeners.')
tcpHCGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 49, 2, 2, 5)).setObjects(*(("TCP-MIB", "tcpHCInSegs"), ("TCP-MIB", "tcpHCOutSegs"),))
if mibBuilder.loadTexts: tcpHCGroup.setDescription('The group of objects providing for counters of high speed\n            TCP implementations.')
mibBuilder.exportSymbols("TCP-MIB", tcpListenerTable=tcpListenerTable, tcpPassiveOpens=tcpPassiveOpens, tcpMIBCompliance2=tcpMIBCompliance2, tcpConnectionProcess=tcpConnectionProcess, tcpRetransSegs=tcpRetransSegs, tcpConnTable=tcpConnTable, tcpListenerLocalAddressType=tcpListenerLocalAddressType, tcpConnectionRemPort=tcpConnectionRemPort, tcpHCInSegs=tcpHCInSegs, tcpOutRsts=tcpOutRsts, tcpListenerEntry=tcpListenerEntry, tcpConnectionLocalAddress=tcpConnectionLocalAddress, tcpInSegs=tcpInSegs, tcpActiveOpens=tcpActiveOpens, tcpAttemptFails=tcpAttemptFails, tcpConnectionTable=tcpConnectionTable, tcpCurrEstab=tcpCurrEstab, tcp=tcp, tcpConnRemAddress=tcpConnRemAddress, tcpEstabResets=tcpEstabResets, tcpConnectionLocalAddressType=tcpConnectionLocalAddressType, tcpMIB=tcpMIB, tcpListenerProcess=tcpListenerProcess, tcpMIBCompliance=tcpMIBCompliance, tcpConnectionGroup=tcpConnectionGroup, tcpConnState=tcpConnState, tcpRtoMin=tcpRtoMin, tcpMIBCompliances=tcpMIBCompliances, tcpHCGroup=tcpHCGroup, tcpBaseGroup=tcpBaseGroup, tcpListenerGroup=tcpListenerGroup, tcpConnectionEntry=tcpConnectionEntry, tcpConnRemPort=tcpConnRemPort, tcpInErrs=tcpInErrs, tcpConnectionState=tcpConnectionState, tcpConnLocalPort=tcpConnLocalPort, tcpRtoMax=tcpRtoMax, tcpConnectionRemAddress=tcpConnectionRemAddress, tcpConnectionRemAddressType=tcpConnectionRemAddressType, tcpMaxConn=tcpMaxConn, tcpMIBConformance=tcpMIBConformance, tcpOutSegs=tcpOutSegs, tcpConnLocalAddress=tcpConnLocalAddress, tcpConnectionLocalPort=tcpConnectionLocalPort, PYSNMP_MODULE_ID=tcpMIB, tcpHCOutSegs=tcpHCOutSegs, tcpListenerLocalAddress=tcpListenerLocalAddress, tcpRtoAlgorithm=tcpRtoAlgorithm, tcpListenerLocalPort=tcpListenerLocalPort, tcpGroup=tcpGroup, tcpMIBGroups=tcpMIBGroups, tcpConnEntry=tcpConnEntry)



#
# PySNMP MIB module IANA-MALLOC-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/IANA-MALLOC-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:15:58 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ConstraintsUnion, SingleValueConstraint, ValueRangeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ConstraintsUnion", "SingleValueConstraint", "ValueRangeConstraint", "ConstraintsIntersection")
( ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup")
( Gauge32, MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, Counter64, iso, Counter32, MibIdentifier, NotificationType, Integer32, ObjectIdentity, Bits, ModuleIdentity, TimeTicks, mib_2, IpAddress, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Gauge32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32", "Counter64", "iso", "Counter32", "MibIdentifier", "NotificationType", "Integer32", "ObjectIdentity", "Bits", "ModuleIdentity", "TimeTicks", "mib-2", "IpAddress")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
ianaMallocMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 102)).setRevisions(("2003-01-27 12:00",))
if mibBuilder.loadTexts: ianaMallocMIB.setLastUpdated('200301271200Z')
if mibBuilder.loadTexts: ianaMallocMIB.setOrganization('IANA')
if mibBuilder.loadTexts: ianaMallocMIB.setContactInfo(' Internet Assigned Numbers Authority\n              Internet Corporation for Assigned Names and Numbers\n              4676 Admiralty Way, Suite 330\n              Marina del Rey, CA 90292-6601\n\n              Phone: +1 310 823 9358\n              EMail: iana@iana.org')
if mibBuilder.loadTexts: ianaMallocMIB.setDescription('This MIB module defines the IANAscopeSource and\n            IANAmallocRangeSource textual conventions for use in MIBs\n            which need to identify ways of learning multicast scope and\n            range information.\n\n            Any additions or changes to the contents of this MIB module\n            require either publication of an RFC, or Designated Expert\n            Review as defined in the Guidelines for Writing IANA\n            Considerations Section document.  The Designated Expert will\n            be selected by the IESG Area Director(s) of the Transport\n            Area.')
class IANAscopeSource(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5,))
    namedValues = NamedValues(("other", 1), ("manual", 2), ("local", 3), ("mzap", 4), ("madcap", 5),)

class IANAmallocRangeSource(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("other", 1), ("manual", 2), ("local", 3),)

mibBuilder.exportSymbols("IANA-MALLOC-MIB", IANAmallocRangeSource=IANAmallocRangeSource, PYSNMP_MODULE_ID=ianaMallocMIB, ianaMallocMIB=ianaMallocMIB, IANAscopeSource=IANAscopeSource)
